@@ -20,7 +20,7 @@
  * A dialog used to select the scale for a network load diagram.
  */
 class ScaleDialog : public KDialogBase {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
