@@ -20,7 +20,7 @@
  * A dialog used to select the update speed for a StatPopup.
  */
 class SpeedDialog : public KDialogBase {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
