@@ -33,7 +33,7 @@ class StatPopup;
  * all of the actions in this window's context menu.
  */
 class StatDock : public KSystemTray {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
